@@ -9,14 +9,14 @@
  */
 #include "test.h"
 #include "screen_buffer.h"
-#include "controller.h"
 
 extern int bail;
 extern struct tseq tseq[];
 extern short e820_nr;
-extern char memsz_mode;
 void performance();
 extern volatile short cpu_mode;
+extern volatile int test;
+extern void find_chunks();
 
 char save[2][POP_H][POP_W];
 char save2[2][POP2_H][POP2_W];
@@ -33,14 +33,10 @@ void get_config()
 		cprint(POP_Y+1,  POP_X+2, "Settings:");
 		cprint(POP_Y+3,  POP_X+6, "(1) Test Selection");
 		cprint(POP_Y+4,  POP_X+6, "(2) Address Range");
-		cprint(POP_Y+5,  POP_X+6, "(3) Memory Sizing");
-		cprint(POP_Y+6,  POP_X+6, "(4) Error Report Mode");
-		cprint(POP_Y+7,  POP_X+6, "(5) Show DMI Memory Info");
-		cprint(POP_Y+8,  POP_X+6, "(6) ECC Mode"); 
-		cprint(POP_Y+9,  POP_X+6, "(7) CPU Selection Mode");
-		cprint(POP_Y+10, POP_X+6, "(8) Refresh Screen");
-		cprint(POP_Y+11, POP_X+6, "(9) Adv. Options");
-		cprint(POP_Y+12,POP_X+6,"(0) Continue");
+		cprint(POP_Y+5,  POP_X+6, "(3) Error Report Mode");
+		cprint(POP_Y+6,  POP_X+6, "(4) CPU Selection Mode");
+		cprint(POP_Y+7,  POP_X+6, "(5) Refresh Screen");
+		cprint(POP_Y+9,POP_X+6,"(0) Continue");
 
 		/* Wait for key release */
 		/* Fooey! This nuts'es up the serial input. */
@@ -53,7 +49,6 @@ void get_config()
 			cprint(POP_Y+3, POP_X+6, "(1) Default Tests");
 			cprint(POP_Y+4, POP_X+6, "(2) Skip Current Test");
 			cprint(POP_Y+5, POP_X+6, "(3) Select Test");
-			cprint(POP_Y+6, POP_X+6, "(4) Select Bit Fade Test");
 			cprint(POP_Y+7, POP_X+6, "(0) Cancel");
 			if (v->testsel < 0) {
 				cprint(POP_Y+3, POP_X+5, ">");
@@ -71,7 +66,7 @@ void get_config()
 					v->testsel = -1;
 					find_ticks_for_pass();
 					sflag++;
-					cprint(LINE_INFO, COL_INF3-3, "Std");
+					cprint(LINE_INFO, 43, "Std");
 					break;
 				case 3:
 					/* Skip test */
@@ -84,32 +79,21 @@ void get_config()
 					cprint(POP_Y+1, POP_X+3,
 						"Test Selection:");
 					cprint(POP_Y+4, POP_X+5,
-						"Test Number [0-9]: ");
+						"Test Number [0-11]: ");
 					i = getval(POP_Y+4, POP_X+24, 0);
-					if (i <= 9) {
+					if (i <= 11) {
 						if (i != v->testsel) {
 							v->pass = -1;
-							v->test = -1;
+							test = -1;
 						}
 						v->testsel = i;
+						find_ticks_for_pass();
+						sflag++;
+                            			bail++;
+						cprint(LINE_INFO, 43, "  #");
+                           			dprint(LINE_INFO, 43, i, 2, 0);
 					}
-					find_ticks_for_pass();
-					sflag++;
-                                        bail++;
-					cprint(LINE_INFO, COL_INF3-4, "  #");
-					dprint(LINE_INFO, COL_INF3-1, i, 1, 0);
 					break;
-				case 5:
-					if (v->testsel != 9) {
-						v->pass = -1;
-						v->test = -1;
-					}
-					v->testsel = 9;
-                                        find_ticks_for_pass();
-                                        sflag++;
-                                        bail++;
-					cprint(LINE_INFO, COL_INF3-2, "#9");
-                                        break;
 				case 11:
 				case 57:
 					sflag++;
@@ -142,10 +126,11 @@ void get_config()
 					page = getval(POP_Y+6, POP_X+9, 12);
 					if (page + 1 <= v->plim_upper) {
 						v->plim_lower = page;
-						v->test--;
+						test--;
 						bail++;
 					}
 					adj_mem();
+					find_chunks();
 					find_ticks_for_pass();
 					sflag++;
 					break;
@@ -163,9 +148,10 @@ void get_config()
 					if  (page - 1 >= v->plim_lower) {
 						v->plim_upper = page;
 						bail++;
-						v->test--;
+						test--;
 					}
 					adj_mem();
+					find_chunks();
 					find_ticks_for_pass();
 					sflag++;
 					break;
@@ -174,9 +160,10 @@ void get_config()
 					v->plim_lower = 0;
 					v->plim_upper =
 						v->pmap[v->msegs - 1].end;
-					v->test--;
+					test--;
 					bail++;
 					adj_mem();
+					find_chunks();
 					find_ticks_for_pass();
 					sflag++;
 					break;
@@ -190,44 +177,7 @@ void get_config()
 			popclear();
 			break;
 		case 4:
-			/* 3 - Memory Sizing */
-			popclear();
-			cprint(POP_Y+1, POP_X+2, "Memory Sizing:");
-			cprint(POP_Y+3, POP_X+6, "(1) BIOS - Std");
-			cprint(POP_Y+4, POP_X+6, "(2) Probe");
-			cprint(POP_Y+5, POP_X+6, "(0) Continue");
-			cprint(POP_Y+2+memsz_mode, POP_X+5, ">");
-			if (!e820_nr) {
-				if (memsz_mode == SZ_MODE_BIOS) {
-					cprint(POP_Y+3, POP_X+5, ">");
-				} else {
-					cprint(POP_Y+4, POP_X+5, ">");
-				}
-			}
-			wait_keyup();
-			while (!sflag) {
-				switch(get_key()) {
-				case 2:
-					memsz_mode = SZ_MODE_BIOS;
-					wait_keyup();
-					restart();
-					break;
-				case 3:
-					memsz_mode = SZ_MODE_PROBE;
-					wait_keyup();
-					restart();
-					break;
-				case 11:
-				case 57:
-					/* 0/CR - Continue */
-					sflag++;
-					break;
-				}
-			}
-			popclear();
-			break;
-		case 5:
-			/* 5 - Error Mode */
+			/* Error Mode */
 			popclear();
 			cprint(POP_Y+1, POP_X+2, "Printing Mode:");
 			cprint(POP_Y+3, POP_X+6, "(1) Error Summary");
@@ -276,49 +226,11 @@ void get_config()
 			}
 			popclear();
 			break;
-		case 6:
-			/* Display DMI Memory Info */
-			pop2up();
-                        print_dmi_info();
-			pop2down();
-                        break;
-		case 7:
-			/* 6 - ECC Polling Mode */
-			popclear();
-			cprint(POP_Y+1, POP_X+2, "ECC Polling Mode:");
-			cprint(POP_Y+3, POP_X+6, "(1) Recommended");
-			cprint(POP_Y+4, POP_X+6, "(2) On");
-			cprint(POP_Y+5, POP_X+6, "(3) Off");
-			cprint(POP_Y+6, POP_X+6, "(0) Cancel");
-			wait_keyup();
-			while(!sflag) {
-				switch(get_key()) {
-				case 2:
-					set_ecc_polling(-1);
-					sflag++;
-					break;
-				case 3:
-					set_ecc_polling(1);
-					sflag++;
-					break;
-				case 4:
-					set_ecc_polling(0);
-					sflag++;
-					break;
-				case 11:
-				case 57:
-					/* 0/CR - Continue */
-					sflag++;
-					break;
-				}
-			}
-			popclear();
-			break;
-		case 8:
-    			/* 7 - CPU Mode */
+		case 5:
+    			/* CPU Mode */
 			popclear();
 			cprint(POP_Y+1, POP_X+2, "CPU Selection Mode:");
-			cprint(POP_Y+3, POP_X+6, "(1) Single");
+			cprint(POP_Y+3, POP_X+6, "(1) Parallel (All)");
 			cprint(POP_Y+4, POP_X+6, "(2) Round Robin");
 			cprint(POP_Y+5, POP_X+6, "(3) Sequential");
 			cprint(POP_Y+6, POP_X+6, "(0) Cancel");
@@ -327,19 +239,23 @@ void get_config()
 			while(!sflag) {
 				switch(get_key()) {
 				case 2:
-					cpu_mode = CPM_SINGLE;
+					if (cpu_mode != CPM_ALL) bail++;
+					cpu_mode = CPM_ALL;
 					sflag++;
-					cprint(LINE_INFO+1,COL_INF3-6,"Single");
+					cprint(7,72,"All   ");
 					break;
 				case 3:
+					if (cpu_mode != CPM_RROBIN) bail++;
 					cpu_mode = CPM_RROBIN;
 					sflag++;
-					cprint(LINE_INFO+1,COL_INF3-6,"RRobin");
+					cprint(7,72,"RRobin");
 					break;
 				case 4:
+					if (cpu_mode != CPM_SEQ) bail++;
 					cpu_mode = CPM_SEQ;
 					sflag++;
-					cprint(LINE_INFO+1,COL_INF3-6,"   Seq");
+					cprint(7,72,"Seq   ");
+					break;
 				case 11:
 				case 57:
 					/* 0/CR - Continue */
@@ -349,39 +265,10 @@ void get_config()
 			}
 			popclear();
 			break;
-		case 9:
+		case 6:
 			reprint_screen = 1;
 			flag++;
 			break;
-                case 10:
-			/* 9 - Advanced Options */
-			popclear();
-			cprint(POP_Y+1, POP_X+2, "Advanced Options:");
-			cprint(POP_Y+3, POP_X+6, "(1) Display SPD Info");
-			cprint(POP_Y+4, POP_X+6, "(2) Modify Memory Timing");
-			cprint(POP_Y+5, POP_X+6, "(0) Cancel");
-			wait_keyup();
-			while (!sflag) {
-				switch(get_key()) {
-				case 2:
-					popdown();
-					show_spd();
-					popup();
-					sflag++;
-					break;
-				case 3:
-					get_menu();
-					sflag++;
-					break;
-				case 11:
-				case 57:
-					/* 0/CR - Continue */
-					sflag++;
-					break;
-				}
-			}
-			popclear();
-			break;
 		case 11:
 		case 57:
 		case 28:
@@ -399,59 +286,6 @@ void get_config()
         }
 }
 
-#ifdef NO
-void performance()
-{ 
-	extern int l1_cache, l2_cache;
-	ulong speed;
-	int i;
-
-	popclear();
-	cprint(POP_Y+1, POP_X+1, "             Read   Write    Copy");
-	cprint(POP_Y+3, POP_X+1, "L1 Cache:");
-	speed=memspeed((ulong)mapping(0x100), (l1_cache/4)*1024, 50, MS_READ);
-	dprint(POP_Y+3, POP_X+10, speed, 6, 0);
-	speed=memspeed((ulong)mapping(0x100), (l1_cache/4)*1024, 50, MS_WRITE);
-	dprint(POP_Y+3, POP_X+17, speed, 6, 0);
-	speed=memspeed((ulong)mapping(0x100), (l1_cache/4)*1024, 50, MS_COPY);
-	dprint(POP_Y+3, POP_X+24, speed, 6, 0);
-
-	if (l2_cache < l1_cache) {
-		i = l1_cache / 4 + l2_cache / 4;
-	} else {
-		i = l1_cache;
-	}
-	cprint(POP_Y+5, POP_X+1, "L2 Cache:");
-	speed=memspeed((ulong)mapping(0x100), i*1024, 50, MS_READ);
-	dprint(POP_Y+5, POP_X+10, speed, 6, 0);
-	speed=memspeed((ulong)mapping(0x100), i*1024, 50, MS_WRITE);
-	dprint(POP_Y+5, POP_X+17, speed, 6, 0);
-	speed=memspeed((ulong)mapping(0x100), i*1024, 50, MS_COPY);
-	dprint(POP_Y+5, POP_X+24, speed, 6, 0);
-
-	/* Determine memory speed.  To find the memory spped we use */
-        /* A block size that is 5x the sum of the L1 and L2 caches */
-        i = (l2_cache + l1_cache) * 5;
-
-        /* Make sure that we have enough memory to do the test */
-        if ((1 + (i * 2)) > (v->plim_upper << 2)) {
-                i = ((v->plim_upper <<2) - 1) / 2;
-        }
-	cprint(POP_Y+7, POP_X+1, "Memory:");
-	speed=memspeed((ulong)mapping(0x100), i*1024, 50, MS_READ);
-	dprint(POP_Y+7, POP_X+10, speed, 6, 0);
-	speed=memspeed((ulong)mapping(0x100), i*1024, 50, MS_WRITE);
-	dprint(POP_Y+7, POP_X+17, speed, 6, 0);
-	speed=memspeed((ulong)mapping(0x100), i*1024, 50, MS_COPY);
-	dprint(POP_Y+7, POP_X+24, speed, 6, 0);
-
-	wait_keyup();
-	while (get_key() == 0);
-	popclear();
-}
-#endif
-	
-
 void popup()
 {
 	int i, j;
