@@ -8,10 +8,10 @@
 #include "config.h"
 #include "smp.h"
 
+extern struct barrier_s *barr;
 extern int test_ticks, nticks;
 extern struct tseq tseq[];
-extern int dmi_err_cnts[MAX_DMI_MEMDEVS];
-extern short dmi_initialized;
+extern volatile int test;
 void poll_errors();
 
 static void update_err_counts(void);
@@ -26,6 +26,7 @@ void error(ulong *adr, ulong good, ulong bad)
 {
 	ulong xor;
 
+	spin_lock(&barr->mutex);
 	xor = good ^ bad;
 #ifdef USB_WAR
 	/* Skip any errrors that appear to be due to the BIOS using location
@@ -38,6 +39,7 @@ void error(ulong *adr, ulong good, ulong bad)
 	}
 #endif
 	common_err(adr, good, bad, xor, 0);
+	spin_unlock(&barr->mutex);
 }
 
 /*
@@ -47,7 +49,9 @@ void error(ulong *adr, ulong good, ulong bad)
  */
 void ad_err1(ulong *adr1, ulong *mask, ulong bad, ulong good)
 {
+	spin_lock(&barr->mutex);
 	common_err(adr1, good, bad, (ulong)mask, 1);
+	spin_unlock(&barr->mutex);
 }
 
 /*
@@ -57,7 +61,9 @@ void ad_err1(ulong *adr1, ulong *mask, ulong bad, ulong good)
  */
 void ad_err2(ulong *adr, ulong bad)
 {
+	spin_lock(&barr->mutex);
 	common_err(adr, (ulong)adr, bad, ((ulong)adr) ^ bad, 0);
+	spin_unlock(&barr->mutex);
 }
 
 static void update_err_counts(void)
@@ -67,7 +73,7 @@ static void update_err_counts(void)
 			"                                            ");
 	}
 	++(v->ecount);
-	tseq[v->test].errors++;
+	tseq[test].errors++;
 		
 }
 
@@ -78,8 +84,10 @@ static void print_err_counts(void)
 
 	if ((v->ecount > 4096) && (v->ecount % 256 != 0)) return;
 
-	dprint(LINE_INFO+1, COL_INF4-8, v->ecount, 8, 0);
-	dprint(LINE_INFO+2, COL_INF4-8, v->ecc_ecount, 8, 0);
+	dprint(LINE_INFO, 70, v->ecount, 6, 0);
+/*
+	dprint(LINE_INFO, 56, v->ecc_ecount, 6, 0);
+*/
 
 	/* Paint the error messages on the screen red to provide a vivid */
 	/* indicator that an error has occured */ 
@@ -98,13 +106,12 @@ static void print_err_counts(void)
  */
 void common_err( ulong *adr, ulong good, ulong bad, ulong xor, int type) 
 {
-	int i, n, x, j, flag=0;
+	int i, n, x, flag=0;
 	ulong page, offset;
 	int patnchg;
 	ulong mb;
 
 	update_err_counts();
-	add_dmi_err((ulong)adr);
 
 	switch(v->printmode) {
 	case PRINTMODE_SUMMARY:
@@ -192,23 +199,7 @@ void common_err( ulong *adr, ulong good, ulong bad, ulong xor, int type)
 			cprint(LINE_HEADER+4, 1,  " Bits in Error - Total:");
 			cprint(LINE_HEADER+4, 29,  "Min:    Max:    Avg:");
 			cprint(LINE_HEADER+5, 1,  " Max Contiguous Errors:");
-			cprint(LINE_HEADER+6, 1,  "ECC Correctable Errors:");
-			cprint(LINE_HEADER+7, 1,  "Errors per Memory Slot:");
 			x = 24;
-			if (dmi_initialized) {
-			  for ( i=0; i < MAX_DMI_MEMDEVS;){
-			    n = LINE_HEADER+7;
-			    for (j=0; j<4; j++) {
-				if (dmi_err_cnts[i] >= 0) {
-					dprint(n, x, i, 2, 0);
-					cprint(n, x+2, ": 0");
-				}
-				i++;
-				n++;
-			    }
-			    x += 10;
-			  }
-			}
 
 			cprint(LINE_HEADER+0, 64,   "Test  Errors");
 			v->erri.hdr_flag++;
@@ -243,17 +234,6 @@ void common_err( ulong *adr, ulong good, ulong bad, ulong xor, int type)
 		  dprint(LINE_HEADER+4, 50, v->erri.tbits/v->ecount, 2, 1);
 		  dprint(LINE_HEADER+5, 25, v->erri.maxl, 7, 1);
 		  x = 28;
-		  for ( i=0; i < MAX_DMI_MEMDEVS;){
-		  	n = LINE_HEADER+7;
-			for (j=0; j<4; j++) {
-				if (dmi_err_cnts[i] > 0) {
-					dprint (n, x, dmi_err_cnts[i], 7, 1);
-				}
-				i++;
-				n++;
-			}
-			x += 10;
-		  }
 			
 		  for (i=0; tseq[i].msg != NULL; i++) {
 			dprint(LINE_HEADER+1+i, 66, i, 2, 0);
@@ -291,7 +271,7 @@ void common_err( ulong *adr, ulong good, ulong bad, ulong xor, int type)
 			offset = ((unsigned long)adr) & 0xFFF;
 		}
 		mb = page >> 8;
-		dprint(v->msg_line, 0, v->test, 3, 0);
+		dprint(v->msg_line, 0, test, 3, 0);
 		dprint(v->msg_line, 4, v->pass, 5, 0);
 		hprint(v->msg_line, 11, page);
 		hprint2(v->msg_line, 19, offset, 3);
@@ -326,7 +306,7 @@ void common_err( ulong *adr, ulong good, ulong bad, ulong xor, int type)
 			v->erri.hdr_flag++;
 		}
 		/* Do not do badram patterns from test 0 or 5 */
-		if (v->test == 0 || v->test == 5) {
+		if (test == 0 || test == 5) {
 			return;
 		}
 		/* Only do patterns for data errors */
@@ -369,7 +349,7 @@ void parity_err( unsigned long edi, unsigned long esi)
 {
 	unsigned long addr;
 
-	if (v->test == 5) {
+	if (test == 5) {
 		addr = esi;
 	} else {
 		addr = edi;
@@ -416,10 +396,32 @@ void printpatn (void)
 /*
  * Show progress by displaying elapsed time and update bar graphs
  */
-void do_tick(void)
+short spin_idx[MAX_CPUS];
+char spin[4] = {'|','/','-','\\'};
+
+void do_tick(int me)
 {
-	int i, n, pct;
-	ulong h, l, t;
+	int i, pct;
+	ulong h, l, n, t;
+	extern int mstr_cpu;
+
+	if (++spin_idx[me] > 3) {
+		spin_idx[me] = 0;
+	}
+	cplace(8, 2*me+7, spin[spin_idx[me]]);
+	
+	/* Check for keyboard input */
+	if (me == mstr_cpu) {
+		check_input();
+	}
+	/* A barrier here holds the other CPUs until the configuration
+	 * changes are done */
+	s_barrier();
+
+	/* Only the first selected CPU does the update */
+	if (me !=  mstr_cpu) {
+		return;
+	}
 
 	/* FIXME only print serial error messages from the tick handler */
 	if (v->ecount) {
@@ -437,13 +439,13 @@ void do_tick(void)
 	} else {
 		pct = 0;
 	}
-	dprint(1, COL_MID+4, pct, 3, 0);
+	dprint(2, COL_MID+4, pct, 3, 0);
 	i = (BAR_SIZE * pct) / 100;
 	while (i > v->tptr) {
 		if (v->tptr >= BAR_SIZE) {
 			break;
 		}
-		cprint(1, COL_MID+9+v->tptr, "#");
+		cprint(2, COL_MID+9+v->tptr, "#");
 		v->tptr++;
 	}
 	
@@ -455,13 +457,13 @@ void do_tick(void)
 	} else {
 		pct = 0;
         }
-	dprint(0, COL_MID+4, pct, 3, 0);
+	dprint(1, COL_MID+4, pct, 3, 0);
 	i = (BAR_SIZE * pct) / 100;
 	while (i > v->pptr) {
 		if (v->pptr >= BAR_SIZE) {
 			break;
 		}
-		cprint(0, COL_MID+9+v->pptr, "#");
+		cprint(1, COL_MID+9+v->pptr, "#");
 		v->pptr++;
 	}
 
@@ -485,7 +487,7 @@ void do_tick(void)
 			}
 			pct += n*3;
 		} else {
-			for (i=0, n=0; i<v->test; i++) {
+			for (i=0, n=0; i<test; i++) {
 				if (tseq[i].errors == 0) {
 					n++;
 				}
@@ -532,21 +534,20 @@ void do_tick(void)
 		t = h * ((unsigned)0xffffffff / v->clks_msec) / 1000;
 		t += (l / v->clks_msec) / 1000;
 		i = t % 60;
-		dprint(LINE_INFO, COL_INF1-1, i%10, 1, 0);
-		dprint(LINE_INFO, COL_INF1-2, i/10, 1, 0);
+		dprint(LINE_INFO, COL_INF1-2, i%10, 1, 0);
+		dprint(LINE_INFO, COL_INF1-3, i/10, 1, 0);
 		t /= 60;
 		i = t % 60;
-		dprint(LINE_INFO, COL_INF1-4, i % 10, 1, 0);
-		dprint(LINE_INFO, COL_INF1-5, i / 10, 1, 0);
+		dprint(LINE_INFO, COL_INF1-5, i % 10, 1, 0);
+		dprint(LINE_INFO, COL_INF1-6, i / 10, 1, 0);
 		t /= 60;
-		dprint(LINE_INFO, COL_INF1-10, t, 4, 0);
+		dprint(LINE_INFO, COL_INF1-11, t, 4, 0);
 	}
 
 
-	/* Check for keyboard input */
-	check_input();
-
 	/* Poll for ECC errors */
+/*
 	poll_errors();
+*/
 }
 
