@@ -25,8 +25,6 @@ int serial_baud_rate = SERIAL_BAUD_RATE;
 unsigned char serial_parity = 0;
 unsigned char serial_bits = 8;
 
-char buf[18];
-
 struct ascii_map_str {
         int ascii;
         int keycode;
@@ -219,6 +217,17 @@ void clear_scroll(void)
         }
 }
 
+/*
+ * Place a single character on screen
+ */
+void cplace(int y, int x, const char c)
+{
+	char *dptr;
+
+	dptr = (char *)(SCREEN_ADR + (160*y) + (2*x));
+	*dptr = c;
+}
+
 /*
  * Print characters on screen
  */
@@ -308,6 +317,7 @@ void dprint(int y, int x, ulong val, int len, int right)
 {
 	ulong j, k;
 	int i, flag=0;
+	char buf[18];
 
 	if (val > 999999999 || len > 9) {
 		return;
@@ -365,6 +375,7 @@ void hprint2(int y,int x, unsigned long val, int digits)
 {
 	unsigned long j;
 	int i, idx, flag = 0;
+	char buf[18];
 
         for (i=0, idx=0; i<8; i++) {
                 j = val >> (28 - (4 * i));
@@ -398,6 +409,7 @@ void hprint3(int y,int x, unsigned long val, int digits)
 {
 	unsigned long j;
 	int i, idx, flag = 0;
+	char buf[18];
 
 	for (i=0, idx=0; i<digits; i++) {
 		j = 0xf & val;
@@ -536,11 +548,6 @@ void inter(struct eregs *trap_regs)
 
 void set_cache(int val) 
 {
-	extern struct cpu_ident cpu_id;
-	/* 386's don't have a cache */
-	if ((cpu_id.cpuid < 1) && (cpu_id.type == 3)) {
-		return;
-	}
 	switch(val) {
 	case 0:
 		cache_off();	
@@ -1085,3 +1092,4 @@ void serial_console_setup(char *param)
 	serial_tty = (short) tty;
 	serial_cons = 1;
 }
+
